#ifndef ADDNOWDIALOG_H
#define ADDNOWDIALOG_H

#include <QDialog>

namespace Ui
{
class addnowDialog;
}

class addnowDialog : public QDialog
{
    Q_OBJECT

public:
    //explicit
    addnowDialog(QWidget *parent = 0);
    addnowDialog(QString rulenow, QWidget *parent = 0);
    int getValue();
    QString getIntf();
    ~addnowDialog();

private:
    Ui::addnowDialog *ui;
};

#endif // ADDNOWDIALOG_H
